@@ -28,7 +28,7 @@ pub fn check_write(
 ) -> AtomicResult<bool> {
     // Check if the resource's write rights explicitly refers to the agent
     if let Ok(arr_val) = resource.get(urls::WRITE) {
-        if arr_val.to_vec()?.contains(&agent) {
+        if arr_val.to_subjects(None)?.contains(&agent) {
             return Ok(true);
         };
     }
@@ -64,7 +64,7 @@ mod test {
         let mut commitbuilder_1 = crate::commit::CommitBuilder::new(subject.into());
         let property = crate::urls::DESCRIPTION;
         let value = Value::new("Some value", &DataType::Markdown).unwrap();
-        commitbuilder_1.set(property.into(), value.clone());
+        commitbuilder_1.set(property.into(), value);
         // let mut commitbuilder_2 = commitbuilder_1.clone();
         // let commit_1 = commitbuilder_1.sign(&agent, &store).unwrap();
         // Should fail if there is no self_url set in the store, and no parent in the commit
