@@ -25,6 +25,7 @@ pub fn populate_base_models(store: &impl Storelike) -> AtomicResult<()> {
             shortname: "shortname".into(),
             description: "A short name of something. It can only contain letters, numbers and dashes `-`. Use dashes to denote spaces between words. Not case sensitive - lowercase only. Useful in programming contexts where the user should be able to type something short to identify a specific thing.".into(),
             subject: urls::SHORTNAME.into(),
+            allows_only: None,
         },
         Property {
             class_type: None,
@@ -32,6 +33,7 @@ pub fn populate_base_models(store: &impl Storelike) -> AtomicResult<()> {
             shortname: "description".into(),
             description: "A textual description of something. When making a description, make sure that the first few words tell the most important part. Give examples. Since the text supports markdown, you're free to use links and more.".into(),
             subject: urls::DESCRIPTION.into(),
+            allows_only: None,
         },
         Property {
             class_type: Some(urls::CLASS.into()),
@@ -39,6 +41,7 @@ pub fn populate_base_models(store: &impl Storelike) -> AtomicResult<()> {
             shortname: "is-a".into(),
             description: "A list of Classes of which the thing is an instance of. The Classes of a Resource determine which Properties are recommended and required.".into(),
             subject: urls::IS_A.into(),
+            allows_only: None,
         },
         Property {
             class_type: Some(urls::DATATYPE_CLASS.into()),
@@ -46,6 +49,7 @@ pub fn populate_base_models(store: &impl Storelike) -> AtomicResult<()> {
             shortname: "datatype".into(),
             description: "The Datatype of a property, such as String or Timestamp.".into(),
             subject: urls::DATATYPE_PROP.into(),
+            allows_only: None,
         },
         Property {
             class_type: Some(urls::CLASS.into()),
@@ -55,6 +59,7 @@ pub fn populate_base_models(store: &impl Storelike) -> AtomicResult<()> {
                 "The class-type indicates that the Atomic URL should be an instance of this class."
                     .into(),
             subject: urls::CLASSTYPE_PROP.into(),
+            allows_only: None,
         },
         Property {
             class_type: Some(urls::PROPERTY.into()),
@@ -62,6 +67,7 @@ pub fn populate_base_models(store: &impl Storelike) -> AtomicResult<()> {
             shortname: "recommends".into(),
             description: "The Properties that are not required, but recommended for this Class.".into(),
             subject: urls::RECOMMENDS.into(),
+            allows_only: None,
         },
         Property {
             class_type: Some(urls::PROPERTY.into()),
@@ -69,6 +75,7 @@ pub fn populate_base_models(store: &impl Storelike) -> AtomicResult<()> {
             shortname: "requires".into(),
             description: "The Properties that are required for this Class.".into(),
             subject: urls::REQUIRES.into(),
+            allows_only: None,
         },
         Property {
             class_type: Some(urls::PROPERTY.into()),
@@ -76,13 +83,22 @@ pub fn populate_base_models(store: &impl Storelike) -> AtomicResult<()> {
             shortname: "parent".into(),
             description: "The parent of a Resource sets the hierarchical structure of the Resource, and therefore also the rights / grants. It is used for both navigation, structure and authorization. Parents are the inverse of [children](https://atomicdata.dev/properties/children).".into(),
             subject: urls::PARENT.into(),
+            allows_only: None,
+        },
+        Property {
+            class_type: Some(urls::PROPERTY.into()),
+            data_type: DataType::AtomicUrl,
+            shortname: "allows-only".into(),
+            description: "Restricts this Property to only the values inside this one. This essentially turns the Property into an `enum`.".into(),
+            subject: urls::ALLOWS_ONLY.into(),
+            allows_only: None,
         }
     ];
 
     let classes = vec![
         Class {
             requires: vec![urls::SHORTNAME.into(), urls::DATATYPE_PROP.into()],
-            recommends: vec![urls::DESCRIPTION.into(), urls::CLASSTYPE_PROP.into(), urls::IS_DYNAMIC.into(), urls::IS_LOCKED.into()],
+            recommends: vec![urls::DESCRIPTION.into(), urls::CLASSTYPE_PROP.into(), urls::IS_DYNAMIC.into(), urls::IS_LOCKED.into(), urls::ALLOWS_ONLY.into()],
             shortname: "property".into(),
             description: "A Property is a single field in a Class. It's the thing that a property field in an Atom points to. An example is `birthdate`. An instance of Property requires various Properties, most notably a `datatype` (e.g. `string` or `integer`), a human readable `description` (such as the thing you're reading), and a `shortname`.".into(),
             subject: urls::PROPERTY.into(),
@@ -91,7 +107,7 @@ pub fn populate_base_models(store: &impl Storelike) -> AtomicResult<()> {
             requires: vec![urls::SHORTNAME.into(), urls::DESCRIPTION.into()],
             recommends: vec![urls::RECOMMENDS.into(), urls::REQUIRES.into()],
             shortname: "class".into(),
-            description: "A Class describes an abstract concept, such as 'Person' or 'Blogpost'. It describes the data shape of data and explains what the thing represents. It is convention to use Uppercase in its URL. Note that in Atomic Data, a Resource can have several Classes - not just a single one.".into(),
+            description: "A Class describes an abstract concept, such as 'Person' or 'Blogpost'. It describes the data shape of data (which fields are required and recommended) and explains what the concept represents. It is convention to use Uppercase in its URL.Resources use the [is-a](https://atomicdata.dev/properties/isA) attribute to indicate which classes they are instances of. Note that in Atomic Data, a Resource can have several Classes - not just a single one.".into(),
             subject: urls::CLASS.into(),
         },
         Class {
