@@ -23,6 +23,7 @@ pub const IS_DYNAMIC: &str = "https://atomicdata.dev/properties/isDynamic";
 pub const IS_LOCKED: &str = "https://atomicdata.dev/properties/isLocked";
 pub const DATATYPE_PROP: &str = "https://atomicdata.dev/properties/datatype";
 pub const CLASSTYPE_PROP: &str = "https://atomicdata.dev/properties/classtype";
+pub const ALLOWS_ONLY: &str = "https://atomicdata.dev/properties/allowsOnly";
 // ... for Classes
 pub const REQUIRES: &str = "https://atomicdata.dev/properties/requires";
 pub const RECOMMENDS: &str = "https://atomicdata.dev/properties/recommends";
@@ -56,7 +57,11 @@ pub const COLLECTION_SORT_BY: &str = "https://atomicdata.dev/properties/collecti
 pub const COLLECTION_SORT_DESC: &str = "https://atomicdata.dev/properties/collection/sortDesc";
 // ... for Endpoints
 pub const ENDPOINT_PARAMETERS: &str = "https://atomicdata.dev/properties/endpoint/parameters";
+pub const ENDPOINT_RESULTS: &str = "https://atomicdata.dev/properties/endpoint/results";
 pub const PATH: &str = "https://atomicdata.dev/properties/path";
+pub const SEARCH_QUERY: &str = "https://atomicdata.dev/properties/search/query";
+pub const SEARCH_LIMIT: &str = "https://atomicdata.dev/properties/search/limit";
+pub const SEARCH_PROPERTY: &str = "https://atomicdata.dev/properties/search/property";
 // ... for Hierarchy / Drive
 pub const PARENT: &str = "https://atomicdata.dev/properties/parent";
 pub const READ: &str = "https://atomicdata.dev/properties/read";
